@@ -53,11 +53,9 @@ func init() {
 	machine.Serial.Configure(machine.UARTConfig{})
 }
 
-func postinit() {}
-
 //export Reset_Handler
 func main() {
 	preinit()
 	run()
-	abort()
+	exit(0)
 }
